audit

package
v1.0.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 16, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Dir

func Dir() string

Dir returns the audit log directory ~/.archery-cli/audit/

func Files

func Files() ([]string, error)

Files returns the list of audit JSONL files in the audit directory, sorted by name. Exported for testing.

func Log

func Log(cmdPath string, args []string, exitCode int, durationMs int64)

Log writes one audit entry to the current month's JSONL file. It is a no-op if ARCHERY_CLI_NO_AUDIT=1. It performs lazy cleanup of old files.

func SetDirForTest

func SetDirForTest(dir string)

SetDirForTest overrides the audit directory. Pass an empty string to reset. Intended for tests only.

Types

This section is empty.

Jump to