Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Files ¶
Files returns the list of audit JSONL files in the audit directory, sorted by name. Exported for testing.
func Log ¶
Log writes one audit entry to the current month's JSONL file. It is a no-op if ARCHERY_CLI_NO_AUDIT=1. It performs lazy cleanup of old files.
func SetDirForTest ¶
func SetDirForTest(dir string)
SetDirForTest overrides the audit directory. Pass an empty string to reset. Intended for tests only.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.